﻿Imports System.IO
Imports ThinkGeo.MapSuite.Core
Imports ThinkGeo.MapSuite.WebEdition

Partial Class MyMapCtl
    Inherits System.Web.UI.UserControl

    Private Const GOOGLELAYERNAME As String = "Google Map"

    Private Class GridItem

        Private _id As Integer
        Public Property Id() As Integer
            Get
                Return _id
            End Get
            Set(ByVal value As Integer)
                _id = value
            End Set
        End Property

        Private _name As String
        Public Property Name() As String
            Get
                Return _name
            End Get
            Set(ByVal value As String)
                _name = value
            End Set
        End Property

        Public Sub New(ByVal id As Integer, ByVal name As String)
            _id = id
            _name = name
        End Sub
    End Class

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        If Not IsPostBack Then
            ctlMap.MapBackground.BackgroundBrush = New GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"))
            ctlMap.CurrentExtent = New RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962)
            ctlMap.MapUnit = GeographyUnit.Meter
            ctlMap.MapTools.Logo.Enabled = False
            ctlMap.MapTools.PanZoomBar.Enabled = True

            'Using Google API string from ThinkGeo samples - we have our own for production
            Dim googleMapKey As String = "http://maps.google.com/maps?file=api&amp;v=2&amp;key=ABQIAAAAoxK_HcqphMsnUQHEwLwHlRSavkNJi0NVTgm4UDidoiIU5dUJpRQW88FufPCp0aTPraxZgZFAIUHn3Q"

            ''This doesn't work - causes "The remote server returned an error: (403) Forbidden"
            'Dim googleMap As New GoogleMapsLayer("Google Map")
            'googleMap.LicenseKey = googleMapKey
            'googleMap.MapType = GoogleMapsMapType.RoadMap
            'ctlMap.StaticOverlay.Layers.Add(googleMap)
            'ctlMap.StaticOverlay.TileType = TileType.SingleTile
            'ctlMap.StaticOverlay.ClientCache.CacheId = "GoogleMapCache"
            'ctlMap.StaticOverlay.ClientCache.Duration = TimeSpan.FromDays(1)

            'This works
            Dim googleLayer As New GoogleOverlay(GOOGLELAYERNAME)
            googleLayer.JavaScriptLibraryUri = New Uri(googleMapKey)
            googleLayer.GoogleMapType = GoogleMapsMapType.RoadMap
            ctlMap.CustomOverlays.Add(googleLayer)

            If File.Exists("~/App_Data/001010.shp") Then
                Dim dirLayer As ShapeFileFeatureLayer
                dirLayer = New ShapeFileFeatureLayer("~/App_Data/001010.shp")
                dirLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.Color = GeoColor.FromArgb(255, GeoColor.SimpleColors.Black)
                dirLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.FillSolidBrush.Color = GeoColor.FromArgb(150, GeoColor.SimpleColors.LightGreen)
                dirLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.City1("DIRID")
                dirLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20
                dirLayer.Name = "D001010"

                Dim proj4 As New Proj4Projection(Proj4Projection.GetEpsgParametersString(4326), Proj4Projection.GetGoogleMapParametersString())
                dirLayer.FeatureSource.Projection = proj4

                Dim shapeOverlay As New LayerOverlay("D001010", False, TileType.SingleTile)
                shapeOverlay.Layers.Add(dirLayer)
                shapeOverlay.TransitionEffect = TransitionEffect.None

                ctlMap.CustomOverlays.Add(shapeOverlay)
                ctlMap.CurrentExtent = GetMapBoundingBox()
            End If

            Dim items As New List(Of GridItem)
            For i As Integer = 0 To 10
                items.Add(New GridItem(i, "Item " & i))
            Next
            grdTest.DataSource = items
            grdTest.DataBind()
        End If

    End Sub

    Private Function GetMapBoundingBox() As RectangleShape
        Dim result As RectangleShape = Nothing

        For layerIdx As Integer = 0 To ctlMap.CustomOverlays.Count - 1
            If ctlMap.CustomOverlays(layerIdx).Name <> GOOGLELAYERNAME Then
                Dim shapeOverlay As LayerOverlay = ctlMap.CustomOverlays(layerIdx)
                Dim l As ShapeFileFeatureLayer = DirectCast(shapeOverlay.Layers(0), ShapeFileFeatureLayer)
                l.FeatureSource.Open()

                Dim feats As System.Collections.ObjectModel.Collection(Of Feature) = l.FeatureSource.GetAllFeatures(New String() {"DIRID"})

                Dim boundingBox As RectangleShape = feats(0).GetBoundingBox()
                If result Is Nothing Then
                    result = boundingBox
                Else
                    result.ExpandToInclude(boundingBox)
                End If

                l.FeatureSource.Close()
            End If
        Next

        If result Is Nothing Then
            result = New RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962)
        End If

        Return result
    End Function

    Protected Sub grdTest_RowCreated(ByVal sender As Object, ByVal e As System.Web.UI.WebControls.GridViewRowEventArgs) Handles grdTest.RowCreated
        If e.Row.RowType = DataControlRowType.DataRow Then
            Dim chk As CheckBox = e.Row.FindControl("chkSelectDir")
            If chk IsNot Nothing Then
                chk.AutoPostBack = True
                AddHandler chk.CheckedChanged, AddressOf SurroundDirCheckChanged
            End If
        End If
    End Sub

    Protected Sub SurroundDirCheckChanged(ByVal sender As Object, ByVal e As EventArgs)
        Dim chk As CheckBox = DirectCast(sender, CheckBox)
    End Sub
End Class
